@@ -448,7 +448,12 @@ impl<'a> Ctx<'a> {
     }
 
     fn lower_const(&mut self, konst: &ast::Const) -> FileItemTreeId<Const> {
-        let name = konst.name().map(|it| it.as_name());
+        let mut name = konst.name().map(|it| it.as_name());
+        if name.as_ref().map_or(false, |n| n.to_string().starts_with("_DERIVE_")) {
+            // FIXME: this is a hack to treat consts generated by synstructure as unnamed
+            // remove this some time in the future
+            name = None;
+        }
         let type_ref = self.lower_type_ref_opt(konst.ty());
         let visibility = self.lower_visibility(konst);
         let ast_id = self.source_ast_id_map.ast_id(konst);
@@ -795,42 +800,42 @@ enum GenericsOwner<'a> {
 
 /// Returns `true` if the given intrinsic is unsafe to call, or false otherwise.
 fn is_intrinsic_fn_unsafe(name: &Name) -> bool {
-    // Should be kept in sync with https://github.com/rust-lang/rust/blob/c6e4db620a7d2f569f11dcab627430921ea8aacf/compiler/rustc_typeck/src/check/intrinsic.rs#L68
+    // Should be kept in sync with https://github.com/rust-lang/rust/blob/0cd0709f19d316c4796fa71c5f52c8612a5f3771/compiler/rustc_typeck/src/check/intrinsic.rs#L72-L105
     ![
         known::abort,
-        known::min_align_of,
-        known::needs_drop,
-        known::caller_location,
-        known::size_of_val,
-        known::min_align_of_val,
         known::add_with_overflow,
-        known::sub_with_overflow,
-        known::mul_with_overflow,
-        known::wrapping_add,
-        known::wrapping_sub,
-        known::wrapping_mul,
-        known::saturating_add,
-        known::saturating_sub,
-        known::rotate_left,
-        known::rotate_right,
-        known::ctpop,
-        known::ctlz,
-        known::cttz,
-        known::bswap,
         known::bitreverse,
+        known::bswap,
+        known::caller_location,
+        known::ctlz,
+        known::ctpop,
+        known::cttz,
         known::discriminant_value,
-        known::type_id,
+        known::forget,
         known::likely,
-        known::unlikely,
-        known::ptr_guaranteed_eq,
-        known::ptr_guaranteed_ne,
+        known::maxnumf32,
+        known::maxnumf64,
+        known::min_align_of,
         known::minnumf32,
         known::minnumf64,
-        known::maxnumf32,
+        known::mul_with_overflow,
+        known::needs_drop,
+        known::ptr_guaranteed_eq,
+        known::ptr_guaranteed_ne,
+        known::rotate_left,
+        known::rotate_right,
         known::rustc_peek,
-        known::maxnumf64,
+        known::saturating_add,
+        known::saturating_sub,
+        known::size_of,
+        known::sub_with_overflow,
+        known::type_id,
         known::type_name,
+        known::unlikely,
         known::variant_count,
+        known::wrapping_add,
+        known::wrapping_mul,
+        known::wrapping_sub,
     ]
     .contains(name)
 }
